import type { JSX, ComponentChildren } from 'preact';
import type { CompositeProps } from '../../types';
type ComponentProps = {
    borderless?: boolean;
    loading?: boolean;
    /**
     * How should AspectRatio fit the contained content?
     */
    objectFit?: 'cover' | 'contain' | 'fill' | 'none' | 'scale-down';
    /**
     * Custom content to show if there are no children, and not in a loading state
     */
    placeholder?: ComponentChildren;
    /**
     * Aspect ratio, expressed as a string. This will be used in a CSS `calc()`
     * expression.
     */
    ratio?: string;
    /**
     * Relative size of border, loading spinner and placeholder content (if using
     * default placeholder content)
     */
    size?: 'sm' | 'md' | 'lg';
};
export type ThumbnailProps = CompositeProps & ComponentProps & Omit<JSX.HTMLAttributes<HTMLElement>, 'size' | 'loading' | 'placeholder'>;
/**
 * Render embedded media (e.g. image), handling aspect ratio, loading state and
 * placeholder content.
 */
export default function Thumbnail({ children, elementRef, borderless, loading, objectFit, placeholder, ratio, size, ...htmlAttributes }: ThumbnailProps): JSX.Element;
export {};
