import type { RefObject } from 'preact';
import type { PresentationalProps, TransitionComponent } from '../../types';
import type { PanelProps } from '../layout/Panel';
type ComponentProps = {
    closeOnClickAway?: boolean;
    closeOnEscape?: boolean;
    closeOnFocusAway?: boolean;
    /**
     * Dialog _should_ be provided with a close handler. We have a few edge use
     * cases, however, in which we need to render a "non-closeable" modal dialog.
     */
    onClose?: () => void;
    /** Accessible title for the close button */
    closeTitle?: string;
    /**
     * Element that should take focus when the Dialog is first rendered. When not
     * provided ("auto"), the dialog's outer element will take focus. Setting this
     * prop to "manual" will opt out of focus routing.
     */
    initialFocus?: RefObject<HTMLOrSVGElement | null> | 'auto' | 'manual';
    /**
     * Restore focus to previously-focused element when unmounted/closed
     */
    restoreFocus?: boolean;
    /**
     * Optional TransitionComponent for open (mount) and close (unmount) transitions
     */
    transitionComponent?: TransitionComponent;
};
export type PanelDialogProps = PresentationalProps & ComponentProps & Omit<PanelProps, 'fullWidthHeader'> & {
    /** Dialog lays out its content in a Panel by default */
    variant?: 'panel';
};
export type CustomDialogProps = PresentationalProps & ComponentProps & {
    /** `custom` allows any layout of Dialog children */
    variant: 'custom';
};
export type DialogProps = PanelDialogProps | CustomDialogProps;
/**
 * Show a dialog
 */
export default function Dialog({ closeOnClickAway, closeOnEscape, closeOnFocusAway, children, initialFocus, restoreFocus, transitionComponent: TransitionComponent, classes, elementRef, onClose, closeTitle, ...rest }: DialogProps): import("preact").JSX.Element;
export {};
